# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Sub-Exporter
Version:	0.991
Release:	1.%{__distinit}%{__distvers}
Summary:	Sophisticated exporter for custom-built routines
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Sub-Exporter
Source0:	https://cpan.metacpan.org/modules/by-module/Sub/Sub-Exporter-%{version}.tar.gz
Patch0:		Sub-Exporter-0.991-old-EU::MM.patch
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.12.0
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Data::OptList) >= 0.1
BuildRequires:	perl(Package::Generator)
BuildRequires:	perl(Params::Util) >= 0.14
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Install) >= 0.92
BuildRequires:	perl(warnings)
# Test suite
BuildRequires:	perl(base)
BuildRequires:	perl(blib)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(subs)
BuildRequires:	perl(Test::More) >= 0.96
# Optional tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
# Extra tests
BuildRequires:	perl(Encode)
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Package::Generator)
# Old provides generator does not support the syntax used in this module
%if 0%{?fedora} < 21 && 0%{?rhel} < 8
Provides:	perl(Sub::Exporter) = %{version}
Provides:	perl(Sub::Exporter::Util) = %{version}
%endif

# Don't want doc-file provides or dependencies
%global our_docdir %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}
%global __provides_exclude_from ^%{our_docdir}/
%global __requires_exclude_from ^%{our_docdir}/

%description
Sub::Exporter provides a sophisticated alternative to Exporter.pm. It allows
for renaming, currying/sub-generation, and other cool stuff.

ACHTUNG! If you're not familiar with Exporter or exporting, read
Sub::Exporter::Tutorial first!

%prep
%setup -q -n Sub-Exporter-%{version}

# Avoid the need for ExtUtils::MakeMaker ≥ 6.78
%patch -P 0

# Fix shellbangs
find t/ -type f -exec \
	perl -MExtUtils::MakeMaker -e 'ExtUtils::MM_Unix->fixin(qw{{}})' \;

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%doc Changes README t/
%dir %{perl_vendorlib}/Sub/
%dir %{perl_vendorlib}/Sub/Exporter/
%{perl_vendorlib}/Sub/Exporter.pm
%{perl_vendorlib}/Sub/Exporter/Util.pm
%doc %{perl_vendorlib}/Sub/Exporter/Cookbook.pod
%doc %{perl_vendorlib}/Sub/Exporter/Tutorial.pod
%{_mandir}/man3/Sub::Exporter.3*
%{_mandir}/man3/Sub::Exporter::Cookbook.3*
%{_mandir}/man3/Sub::Exporter::Tutorial.3*
%{_mandir}/man3/Sub::Exporter::Util.3*

%changelog
* Fri Nov 24 2023 Paul Howarth <paul@city-fan.org> - 0.991-1
- Update to 0.991
  - Make the requirement for perl v5.12.0 explicit; previously, it was only
    implicit because of prerequisites

* Sat Jul 22 2023 Paul Howarth <paul@city-fan.org> - 0.990-1
- Update to 0.990
  - Fixes to keep working in v5.39 (GH#17, GH#18)

* Thu Jul 13 2023 Paul Howarth <paul@city-fan.org> - 0.989-2
- Avoid use of deprecated patch syntax

* Sun Jan  1 2023 Paul Howarth <paul@city-fan.org> - 0.989-1
- Update to 0.989
  - Update author contact info
- Use SPDX-format license tag

* Mon Jun 21 2021 Paul Howarth <paul@city-fan.org> - 0.988-1
- Update to 0.988
  - Update author contact info
  - Add perl support section to docs
- Add patch to support building with ExtUtils::MakeMaker < 6.78

* Tue Mar 10 2020 Paul Howarth <paul@city-fan.org> - 0.987-22
- BR: perl(blib) for t/00-compile.t
- Fix shellbangs in a more robust way

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 0.987-19
- Perl 5.30 rebuild

* Thu Apr 12 2018 Paul Howarth <paul@city-fan.org> - 0.987-15
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workarounds for building with Test::More < 0.94

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 0.987-10
- Fix FTBFS when perl is not in the minimal buildroot
- Simplify find command using -delete
- BR: perl-generators where available

* Thu Jan  7 2016 Paul Howarth <paul@city-fan.org> - 0.987-7
- Don't use %%define

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.987-3
- Drop %%defattr, redundant since rpm 4.4
- Drop support for building with ExtUtils::MakeMaker < 6.30

* Sat Oct 19 2013 Paul Howarth <paul@city-fan.org> - 0.987-1
- Update to 0.987 (update bugtracker metadata)
- Update patches as needed

* Wed Jul 31 2013 Paul Howarth <paul@city-fan.org> - 0.986-3
- Handle filtering of provides/requires from unversioned doc-dirs from F-20

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 0.986-2
- Perl 5.18 rebuild

* Sat Jun 15 2013 Paul Howarth <paul@city-fan.org> - 0.986-1
- Update to 0.986 (typo fixes in docs)
- Use metacpan URLs

* Thu Feb 21 2013 Paul Howarth <paul@city-fan.org> - 0.985-1
- Update to 0.985 (documentation fixes)
- Add patch to support building with Test::More < 0.88
- Only apply patches when needed
- BR: perl(File::Find), perl(File::Temp) and perl(subs) for test suite
- Bump perl(Test::Pod) version requirement to 1.41

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> - 0.984-2
- BR: perl(base), perl(Exporter), perl(lib) and perl(Test::Pod)
- Run the release tests too

* Tue Jun  5 2012 Paul Howarth <paul@city-fan.org> - 0.984-1
- Update to 0.984 (documentation fixes)
- Add filters for Test::SubExporter modules in tests
- Add patch to support building with ExtUtils::MakeMaker < 6.30

* Sat Mar  3 2012 Paul Howarth <paul@city-fan.org> - 0.982-10
- BR: perl(Carp)
- Explicitly require perl(Package::Generator)
- Drop explicit runtime dependency on perl(Exporter); it's automatically
  detected by rpm ≥ 4.9 and it's not needed prior to that
- No need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - No need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 0.982-8
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.982-5
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 31 2010 Paul Howarth <paul@city-fan.org> - 0.982-4
- Fix dist tag for RHEL-6 Beta

* Wed Mar  3 2010 Paul Howarth <paul@city-fan.org> - 0.982-3
- Add manual dep for perl(Exporter) - "use base Exporter"
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> - 0.982-2
- Define RPM macros in global scope

* Thu Jan 29 2009 Paul Howarth <paul@city-fan.org> - 0.982-1
- Update to 0.982

* Thu Oct 23 2008 Paul Howarth <paul@city-fan.org> - 0.981-1
- Update to 0.981

* Mon Sep 15 2008 Paul Howarth <paul@city-fan.org> - 0.980-1
- Update to 0.980
- Re-add buildreq perl(Package::Generator)

* Tue Sep  2 2008 Paul Howarth <paul@city-fan.org> - 0.979-2
- Import from Fedora
- Drop buildreq perl(Package::Generator) for now
- Make %%files list more explicit and mark pod files as %%doc

* Mon Jun 30 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.979-1
- Update to 0.979
- Drop BR's on: perl(Test::Pod::Coverage), perl(Test::Pod)

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.978-2
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.978-1
- Update to 0.978
- Fix license tag
- Rebuild for new perl

* Thu Aug 09 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.975-1
- Update to 0.975

* Fri Jun 01 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.974-1
- Update to 0.974

* Sat Dec 09 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.972-1
- Update to 0.972

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.970-2
- Bump

* Sat Sep 02 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.970-1
- Specfile autogenerated by cpanspec 1.69.1
